#!/bin/bash
declare Version=1.2.2

#------------------------------------------------------------------------------
# This wrapper to test_cbd.sh defines recommended flags for use with Vagrant
# VM testing, and in general handles the vagaries of operatring in a
# Vagrant VM environment.
set -u

function bail () { echo -e "\nError: ${1:-Unknown Error}\n"; exit ${2:-1}; }

export CBD_HOME=/p4/common/bin/cbd
export CBD_BRANCH=${CBD_BRANCH:-main}

# Deploy from a Perforce server.  The user indicated should be a
# non-password user.  Only read permissions are needed.
declare DeployServerP4PORT=workshop.perforce.com:1666
declare DeployServerP4USER=ftp
declare DeployServerP4CLIENT=perforce-software.cbd_${CBD_BRANCH}.deploy

declare CbdDir=/depotdata${CBD_HOME}
declare LibDir=/p4/common/lib
declare RunUser=perforce
declare RunGroup=perforce
declare RunHost=helix-01
declare SudoUser=vagrant
declare TestSuiteCmd=
declare CopyOfThisScript

if [[ `id -u` = 0 || "`id -u -n`" == $SudoUser ]]; then
   CopyOfThisScript=/tmp/${0##*/}
   sudo cp -p $0 $CopyOfThisScript
   sudo chmod 740 $CopyOfThisScript
   sudo chown $RunUser:$RunGroup $CopyOfThisScript
   exec sudo su -l $RunUser -c "$CopyOfThisScript $*"
elif [[ "`id -u -n`" != $RunUser ]]; then
   echo "$0 can only be run by root, $RunUser, or $SudoUser on host $RunHost."
   exit 1
fi

if [[ ${HOSTNAME%%.*} != $RunHost ]]; then
   echo "$0 can only be run by root, $RunUser, or $SudoUser on host $RunHost."
fi

echo "Running ${0##*/} v$Version as user $USER on host ${HOSTNAME%%.*}."

chownCmd="sudo chown -R $RunUser:$RunGroup /depotdata /p4"
echo "Running: $chownCmd"
$chownCmd

if [[ -d /p4 ]]; then
   if [[ -L /p4/common ]]; then
      echo "Verified: SDP /p4/common symlink exists."
   else
      echo "Making SDP symlink in /p4."
      cd /p4
      linkCmd="sudo ln -s /depotdata/p4/common"
      echo "Running: $linkCmd"
      $linkCmd || bail "SDP symlink not created. Aborting."
   fi
else
   bail "Expected /p4 directory does not exist. Aborting."
fi

flushCmd="p4 -p $DeployServerP4PORT -u $DeployServerP4USER -c $DeployServerP4CLIENT flush"
echo "Running: $flushCmd"
$flushCmd

cleanCmd="p4 -p $DeployServerP4PORT -u $DeployServerP4USER -c $DeployServerP4CLIENT -d /p4/common clean"
echo "Running: $cleanCmd"
$cleanCmd

TestSuiteCmd="$CBD_HOME/test/test_cbd.sh -I -S"
echo -e "Running the Test Suite, executing:\n$TestSuiteCmd"

$TestSuiteCmd || bail "Test Suite Failed."

echo -e "SUCCESS: Test Suite Completed OK."

exit 0
